testtools
=========

.. automodule:: abjad.tools.testtools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.testtools.BenchmarkScoreMaker.BenchmarkScoreMaker.BenchmarkScoreMaker

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.testtools.apply_additional_layout.apply_additional_layout
      ~abjad.tools.testtools.compare.compare
      ~abjad.tools.testtools.read_test_output.read_test_output
      ~abjad.tools.testtools.write_test_output.write_test_output
